<?php
/*
Plugin Name: nanoSlider
Description: Portage of the Nivo Slider. Possible image source : one list of URLs or Picasa/Google+ album
Version: 1.0.3
Author: Christophe Brisbois
Author URI: http://www.brisbois.fr/
*/

# get correct id for plugin
$thisfile=basename(__FILE__, ".php");

# register plugin
register_plugin(
	$thisfile, 						//Plugin id
	'nanoSlider', 					//Plugin name
	'1.0.3', 						//Plugin version
	'Christophe Brisbois',  		//Plugin author
	'http://www.brisbois.fr/',		//author website
	'<b>Portage of the Nivo Slider.</b><br> Supported image source : one list of URLs or one Picasa/Google+ photo album', //Plugin description
	'pages', 						//page type - on which admin tab to display
	'nanoSlider_show'				//main function (administration)
);

# activate filter 
add_filter('content','nanoSlider'); 
add_action('index-pretemplate','nanoSlider_check'); 
queue_script('jquery', GSFRONT);


class nanoSlider_slider {
	var $_kind='';
    var $_userID='';
    var $_albumName='';
	var $_maxWidth='';
	var $_displayCaption=false;
	var $_theme='default';
	var $_nivoOptions='';
	var $_listImages='';
	var $_listImagesBaseURL='';
	var $_listCaptions='';
	var $_forceJQuery=false;
	var $_consistencyError='';

	// check the consistency of the parameters
	public function checkConsistency() {
	
		if( empty($this->_kind) OR ($this->_kind != 'picasa' AND $this->_kind != 'url') ) {
			$this->_consistencyError='Incorrect parameters for nanoSlider. Please define the "kind". Possible values : "url", "picasa".'.$this->_kind;
			return false;
		}
		

		if( $this->_kind == 'picasa' AND !empty($this->_userID)  ) {
			return true;
		}

		if( $this->_kind == 'url' AND !empty($this->_listImages)  ) {
			return true;
		}

//		if( $this->_stringFound ) {
//			$this->_consistencyError='Incorrect parameters for nanoSlider. Please check the settings in your page.';
//			return false;
//		}
		$this->_consistencyError='Incorrect parameters for nanoSlider. Please check the settings in your page.';
		return false;
		
	}

	
	// build the parameter string to pass to the javascript
	public function jsParams() {
		$s="{";
		switch( $this->_kind ){
			case "picasa":
				if( !empty($this->_userID) ) { $s.="'userID':'".$this->_userID."',"; } 
				if( !empty($this->_albumName) ) { $s.="'albumName':'".$this->_albumName."',"; } 
				break;
			case "url":
				if( !empty($this->_listImages) ) { $s.="'listImages':'".$this->_listImages."',"; } 
				if( !empty($this->_listImagesBaseURL) ) { $s.="'listImagesBaseURL':'".$this->_listImagesBaseURL."',"; } 
				if( !empty($this->_listCaptions) ) { $s.="'listCaptions':'".$this->_listCaptions."',"; } 
				break;
		}
		if( !empty($this->_maxWidth) ) { $s.="'maxWidth':'".$this->_maxWidth."',"; } 
		if( !empty($this->_theme) ) { $s.="'theme':'".$this->_theme."',"; } 
		if( !empty($this->_kind) ) { $s.="'kind':'".$this->_kind."',"; } 
		if( !empty($this->_displayCaption) ) { $s.="'displayCaption':'".$this->_displayCaption."',"; } 
		
		if ( strlen($s) == 1 ) { return ""; }

		$s=substr($s,0,strlen($s)-1)."}";
		return $s;
	}
}

class nanoSlider_parsedContent {
	var $_sliders;
	var $_newContent='';
	
	function __construct($content) {
		$this->_sliders=array();
		$this->_newContent=$content;
		$ok=true;
		do{
			$ok=$this->parseContent();
		} while( $ok );
	}
	
	function parseContent() {
		$p1 = strpos($this->_newContent, '(%nanoslider');
		if ( $p1 === false ){  return false; };
		$p2= strpos($this->_newContent, '%)', $p1+2);
		if ( $p2 === false ){  return false; };

		$n=count($this->_sliders);

		$this->_sliders[$n]=new nanoSlider_slider();
		$tmp=substr($this->_newContent, $p1+12, $p2-$p1-12);
		// replace the settings with the DIV container in the page
		$this->_newContent=substr($this->_newContent,0,$p1)."<div id='nanoSlider".$n."' class='nanoSlider'></div>".substr($this->_newContent,$p2+2);

		$tmp=html_entity_decode($tmp);
		$tmp=str_replace('<p>','',$tmp);
		$tmp=str_replace('</p>','',$tmp);
		$tmp=str_replace('&nbsp;','',$tmp);
		$tmp=str_replace('&amp;','&',$tmp);
		$tmp=str_replace('<br>','',$tmp);
		$tmp=str_replace('<br />','',$tmp);
		$tmp=str_replace(' ','',$tmp);
		$tmp=str_replace('\"','"',$tmp);
		$tmp=str_replace(array("\t", "\n", "\r"),'',$tmp);
		parse_str($tmp,$fields);

		// get parameters value
		if( isset($fields['kind']) ) { $this->_sliders[$n]->_kind=$fields['kind']; }
		if( isset($fields['userID']) ) { $this->_sliders[$n]->_userID=$fields['userID']; }
		if( isset($fields['maxWidth']) ) { $this->_sliders[$n]->_maxWidth=$fields['maxWidth']; }
		if( isset($fields['album']) ) { $this->_sliders[$n]->_albumName=$fields['album']; }
		if( isset($fields['theme']) ) { $this->_sliders[$n]->_theme=$fields['theme']; }
		if( isset($fields['listImages']) ) { $this->_sliders[$n]->_listImages=$fields['listImages']; }
		if( isset($fields['listImagesBaseURL']) ) { $this->_sliders[$n]->_listImagesBaseURL=$fields['listImagesBaseURL']; }
		if( isset($fields['listCaptions']) ) { $this->_sliders[$n]->_listCaptions=$fields['listCaptions']; }
		if( isset($fields['displayCaption']) ) { $this->_sliders[$n]->_displayCaption=$fields['displayCaption']; }
		if( isset($fields['forceJQuery']) ) { 
			if( $fields['forceJQuery'] == 'true' ) { $this->_sliders[$n]->_forceJQuery=$fields['forceJQuery']; }
		}
		
		
		if( isset($fields['nivoOptions']) ) {
			$this->_sliders[$n]->_nivoOptions=$fields['nivoOptions'];
			$this->_sliders[$n]->_nivoOptions=strtolower($this->_sliders[$n]->_nivoOptions);
			// restore the case of the nivoslider options
			$this->_sliders[$n]->_nivoOptions=str_replace('pauseonhover','pauseOnHover',$this->_sliders[$n]->_nivoOptions);
			$this->_sliders[$n]->_nivoOptions=str_replace('randomstart','randomStart',$this->_sliders[$n]->_nivoOptions);
			$this->_sliders[$n]->_nivoOptions=str_replace('boxrows','boxRows',$this->_sliders[$n]->_nivoOptions);
			$this->_sliders[$n]->_nivoOptions=str_replace('animspeed','animSpeed',$this->_sliders[$n]->_nivoOptions);
			$this->_sliders[$n]->_nivoOptions=str_replace('pausetime','pauseTime',$this->_sliders[$n]->_nivoOptions);
			$this->_sliders[$n]->_nivoOptions=str_replace('startslide','startSlide',$this->_sliders[$n]->_nivoOptions);
			$this->_sliders[$n]->_nivoOptions=str_replace('directionnav','directionNav',$this->_sliders[$n]->_nivoOptions);
			$this->_sliders[$n]->_nivoOptions=str_replace('controlnav','controlNav',$this->_sliders[$n]->_nivoOptions);
			$this->_sliders[$n]->_nivoOptions=str_replace('controlnavthumbs','controlNavThumbs',$this->_sliders[$n]->_nivoOptions);
			$this->_sliders[$n]->_nivoOptions=str_replace('manualadvance','manualAdvance',$this->_sliders[$n]->_nivoOptions);
			$this->_sliders[$n]->_nivoOptions=str_replace('prevtext','prevText',$this->_sliders[$n]->_nivoOptions);
			$this->_sliders[$n]->_nivoOptions=str_replace('nexttext','nextText',$this->_sliders[$n]->_nivoOptions);
		}

		return true;
	}

}


class nanoSlider_nanoParams {
	var $_kind='';
    var $_userID='';
    var $_albumName='';
	var $_maxWidth='';
	var $_theme='default';
	var $_nivoOptions='';
	var $_newContent='';
	var $_stringFound=false;
	var $_listImages='';
	var $_listImagesBaseURL='';
	var $_listCaptions='';
	var $_consistencyError='';
	
	// parse the page content and extract the parameters
	function __construct($content) {
		
		$p1 = strpos($content, '(%nanoslider');
		if ( $p1 === false ){  return false; };
		$this->_stringFound=true;
		$p2= strpos($content, '%)', $p1+2);
		if ( $p2 === false ){  return false; };
		
		// replace settings with the DIV container
		$this->_newContent=substr($content,0,$p1)."<div id='nanoSlider'></div>".substr($content,$p2+2);

		$tmp=strtolower (substr($content, $p1+12, $p2-$p1-12));
		$tmp=html_entity_decode($tmp);
		$tmp=str_replace('<p>','',$tmp);
		$tmp=str_replace('</p>','',$tmp);
		$tmp=str_replace('&amp;','&',$tmp);
		$tmp=str_replace('\"','"',$tmp);
		$tmp=str_replace(array("\t", "\n", "\r"),'',$tmp);
		parse_str($tmp,$fields);
		
		// get parameters value
		if( isset($fields['kind']) ) { $this->_kind=$fields['kind']; }
		if( isset($fields['userid']) ) { $this->_userID=$fields['userid']; }
		if( isset($fields['maxwidth']) ) { $this->_maxWidth=$fields['maxwidth']; }
		if( isset($fields['album']) ) { $this->_albumName=$fields['album']; }
		if( isset($fields['theme']) ) { $this->_theme=$fields['theme']; }
		
		if( isset($fields['nivooptions']) ) {
			$this->_nivoOptions=$fields['nivooptions'];
			// restore the case of the nivoslider options
			$this->_nivoOptions=str_replace('pauseonhover','pauseOnHover',$this->_nivoOptions);
			$this->_nivoOptions=str_replace('randomstart','randomStart',$this->_nivoOptions);
			$this->_nivoOptions=str_replace('boxrows','boxRows',$this->_nivoOptions);
			$this->_nivoOptions=str_replace('animspeed','animSpeed',$this->_nivoOptions);
			$this->_nivoOptions=str_replace('pausetime','pauseTime',$this->_nivoOptions);
			$this->_nivoOptions=str_replace('startslide','startSlide',$this->_nivoOptions);
			$this->_nivoOptions=str_replace('directionnav','directionNav',$this->_nivoOptions);
			$this->_nivoOptions=str_replace('controlnav','controlNav',$this->_nivoOptions);
			$this->_nivoOptions=str_replace('controlnavthumbs','controlNavThumbs',$this->_nivoOptions);
			$this->_nivoOptions=str_replace('manualadvance','manualAdvance',$this->_nivoOptions);
			$this->_nivoOptions=str_replace('prevtext','prevText',$this->_nivoOptions);
			$this->_nivoOptions=str_replace('nexttext','nextText',$this->_nivoOptions);
		}

	}
	
	// check the prsence of the (%nanoslider...%) and check the consistency of the parameters
	public function check() {
	
		if( empty($this->_kind) OR ($this->_kind != 'picasa' AND $this->_kind != 'url') ) {
			$this->_consistencyError='Incorrect parameters for nanoSLIDER. Please define the "kind". Possible values : "url", "picasa".'.$this->_kind;
			return false;
		}

		if( !empty($this->_userID) AND !empty($this->_maxWidth)  ) {
			return true;
		}

		if( $this->_stringFound ) {
			$this->_consistencyError='Incorrect parameters for nanoSLIDER. Please check the settings in your page.';
			return false;
		}
	}
	
	// build the parameter string to pass to the javascript
	public function jsParams() {
		$s="{";
		
		if( !empty($this->_userID) ) { $s.="'userID':'".$this->_userID."',"; } 
		if( !empty($this->_maxWidth) ) { $s.="'maxWidth':'".$this->_maxWidth."',"; } 
		if( !empty($this->_albumName) ) { $s.="'albumName':'".$this->_albumName."',"; } 
		if( !empty($this->_theme) ) { $s.="'theme':'".$this->_theme."',"; } 
		
		if ( strlen($s) == 1 ) { return ""; }

		$s=substr($s,0,strlen($s)-1)."}";
		return $s;
	}
}



function nanoSlider_check() {
    global $data_index;	
	if (strpos($data_index->content, '(%nanoslider') === false ){  return false; };
	add_action('theme-header','nanoSlider_header');
};

function nanoSlider_header() {
    
    global $data_index;	
	global $SITEURL;
	
	if (strpos($data_index->content, '(%nanoslider') === false ){  return false; };
	$mp = new nanoSlider_parsedContent($data_index->content);

    $tmpContent='<meta name="generator" content="GetSimple nanoSLIDER">'."\n";
    $tmpContent.='<link href="'.$SITEURL.'/plugins/nanoslider/nivoslider/nivo-slider.css" rel="stylesheet" type="text/css">'."\n";
	$tmpContent.='<link href="'.$SITEURL.'/plugins/nanoslider/nivoslider/themes/default/default.css" rel="stylesheet" type="text/css" media="screen">'."\n";
	for( $i=0; $i<count($mp->_sliders); $i++ ) {
		if( strlen($mp->_sliders[$i]->_theme) > 0 and $mp->_sliders[$i]->_theme != 'default' ) {
			$tmpContent.='<link href="'.$SITEURL.'/plugins/nanoslider/nivoslider/themes/'.$mp->_sliders[$i]->_theme.'/'.$mp->_sliders[$i]->_theme.'.css" rel="stylesheet" type="text/css" media="screen">'."\n";
		}
	}
	
	for( $i=0; $i<count($mp->_sliders); $i++ ) {
		if( $mp->_sliders[$i]->_forceJQuery ==  true ) {
			$tmpContent.='<script type="text/javascript" src="'.$SITEURL.'/plugins/nanoslider/js/jquery-1.8.2.min"></script>'."\n";
			break;
		}
	}
    $tmpContent.='<script type="text/javascript" src="'.$SITEURL.'/plugins/nanoslider/nivoslider/jquery.nivo.slider.pack.js"></script>'."\n";
    $tmpContent.='<link href="'.$SITEURL.'/plugins/nanoslider/css/nanoslider.css" rel="stylesheet" type="text/css">'."\n";
    $tmpContent.='<script type="text/javascript" src="'.$SITEURL.'/plugins/nanoslider/js/nanoslider.js"></script>'."\n";
    $tmpContent.='<script>'."\n";
    $tmpContent.='  jQuery(document).ready(function () {'."\n";
	for( $i=0; $i<count($mp->_sliders); $i++ ) {
		$tmpContent.="    nanoSLIDER.Initiate('nanoSlider".$i."',".$mp->_sliders[$i]->jsParams().",'".$mp->_sliders[$i]->_nivoOptions."','".$mp->_sliders[$i]->_theme."',".$i.");"."\n";
	}
    $tmpContent.='  });'."\n";
    $tmpContent.='</script>'."\n";
    
    echo $tmpContent;
};

function nanoSlider($content) {
	
	if (strpos($content, '(%nanoslider') === false ){  return $content; };
	$mp = new nanoSlider_parsedContent($content);
	for( $i=0; $i<count($mp->_sliders); $i++ ) {
		if( $mp->_sliders[$i]->checkConsistency() === false ) {
			return $mp->_sliders[$i]->_consistencyError;
		}
	}
	
	return $mp->_newContent;
}

function nanoSlider_show() {
	#echo '<p>I like to echo "Hello World" in the footers of all themes.</p>';
}

?>